@@ -638,33 +638,6 @@ LALFindChirpFilterSegment (
     FindChirpFilterParams      *params
     );
 
-void
-LALFindChirpStoreEvent (
-    LALStatus                  *status,
-    FindChirpFilterInput       *input,
-    FindChirpFilterParams      *params,
-    SnglInspiralTable          *thisEvent,
-    COMPLEX8                   *q,
-    UINT4                       kmax,
-    REAL4                       norm,
-    UINT4                       eventStartIdx,
-    UINT4                       numChisqBins,
-    CHAR                       *searchName
-    );
-
-void
-LALFindChirpClusterEvents (
-    LALStatus                  *status,
-    SnglInspiralTable         **eventList,
-    FindChirpFilterInput       *input,
-    FindChirpFilterParams      *params,
-    FindChirpBankVetoData      *bankVetoData,
-    UINT4                       subBankIndex,
-    int                         writeCData,
-    InspiralTemplate           *bankCurrent
-    );
-
-
 void
 LALFindChirpFilterOutputVeto(
     LALStatus                          *status,
