@@ -285,12 +285,6 @@ LALCompareSnglInspiralByTime (
     const void *b
     );
 
-int
-LALCompareSnglInspiralByID (
-     const void *a,
-     const void *b
-     );
-
 void
 LALCompareSnglInspiral (
     LALStatus                *status,
@@ -497,53 +491,6 @@ XLALAddSnglInspiralCData(
     );
 
 /* coinc inspiral */
-void
-LALCreateTwoIFOCoincList(
-    LALStatus                  *status,
-    CoincInspiralTable        **coincOutput,
-    SnglInspiralTable          *snglInput,
-    InspiralAccuracyList       *accuracyParams
-    );
-
-void
-LALCreateNIFOCoincList(
-    LALStatus                  *status,
-    CoincInspiralTable        **coincHead,
-    InspiralAccuracyList       *accuracyParams,
-    INT4                        N
-    );
-
-void
-LALRemoveRepeatedCoincs(
-    LALStatus                  *status,
-    CoincInspiralTable        **coincHead
-    );
-
-void
-LALFreeCoincInspiral(
-    LALStatus                  *status,
-    CoincInspiralTable        **coincPtr
-    );
-
-int
-XLALFreeCoincInspiral(
-    CoincInspiralTable        **coincPtr
-    );
-
-
-void
-LALAddSnglInspiralToCoinc(
-    LALStatus                  *status,
-    CoincInspiralTable        **coincPtr,
-    SnglInspiralTable          *snglInspiral
-    );
-
-CoincInspiralTable *
-XLALAddSnglInspiralToCoinc(
-    CoincInspiralTable         *coincInspiral,
-    SnglInspiralTable          *snglInspiral
-    );
-
 void
 XLALSnglInspiralCoincTest(
     CoincInspiralTable         *coincInspiral,
@@ -559,101 +506,12 @@ LALSnglInspiralCoincTest(
     InspiralAccuracyList       *accuracyParams
     );
 
-void
-XLALInspiralPsi0Psi3CutBCVC(
-    CoincInspiralTable        **coincInspiral
-    );
-
-void
-XLALInspiralIotaCutBCVC(
-    CoincInspiralTable        **coincInspiral,
-    InspiralAccuracyList       *accuracyParams
-    );
-
-void
-LALInspiralDistanceCutCleaning(
-    LALStatus                  *status,
-    CoincInspiralTable        **coincInspiral,
-    InspiralAccuracyList       *accuracyParams,
-    REAL4 			snrThreshold,
-    SummValueTable             *summValueList,
-    LALSegList                 *vetoSegsH1,
-    LALSegList                 *vetoSegsH2
-    );
-
-void
-XLALInspiralDistanceCutBCVC(
-    CoincInspiralTable        **coincInspiral,
-    InspiralAccuracyList       *accuracyParams
-    );
-
-void
-XLALInspiralDistanceCut(
-    CoincInspiralTable        **coincInspiral,
-    InspiralAccuracyList       *accuracyParams
-    );
-
-void
-XLALInspiralSNRCutBCV2(
-    CoincInspiralTable        **coincInspiral
-    );
-
-SnglInspiralTable *
-XLALExtractSnglInspiralFromCoinc(
-    CoincInspiralTable         *coincInspiral,
-    LIGOTimeGPS                *gpsStartTime,
-    INT4                        slideNum
-    );
-
-void
-LALExtractSnglInspiralFromCoinc(
-    LALStatus                  *status,
-    SnglInspiralTable         **snglPtr,
-    CoincInspiralTable         *coincInspiral,
-    LIGOTimeGPS                *gpsStartTime,
-    INT4                        slideNum
-    );
-
 int
 XLALCreateCoincSlideTable(
     CoincInspiralSlideTable   **slideTableHead,
     INT4                        numSlides
     );
 
-REAL4
-XLALSetupCoincSlideTable(
-    CoincInspiralSlideTable    *slideTableHead,
-    CoincInspiralTable         *coincSlideHead,
-    char                       *timeAnalyzedFileName,
-    REAL4                       timeModifier,
-    INT4                        numSlides
-    );
-
-int
-XLALRecreateCoincFromSngls(
-    CoincInspiralTable        **coincPtr,
-    SnglInspiralTable         **snglInspiral
-    );
-
-void
-LALCoincCutSnglInspiral(
-    LALStatus                  *status,
-    SnglInspiralTable         **snglPtr
-    );
-
-int
-XLALGenerateCoherentBank(
-    SnglInspiralTable         **coherentBank,
-    CoincInspiralTable         *coincInput,
-    CohbankRunType              runType,
-    INT8                        ringStartNS,
-    INT8                        ringEndNS,
-    int                         numSlides,
-    REAL8                       slideStep[LAL_NUM_IFO],
-    REAL4                       eff_snrsq_threshold,
-    CHAR                       *ifos
-    );
-
 INT8
 XLALCoincInspiralTimeNS (
     const CoincInspiralTable         *coincInspiral
@@ -671,14 +529,6 @@ int XLALComputeAndStoreEffectiveSNR(   	CoincInspiralTable *head,
 					CoincInspiralStatParams *par
     );
 
-int
-XLALClusterCoincInspiralTable (
-    CoincInspiralTable        **coincList,
-    INT8                        dtimeNS,
-    CoincInspiralStatistic      coincStat,
-    CoincInspiralStatParams *bittenLParams
-    );
-
 int
 XLALCompareCoincInspiralByTime (
     const void *a,
@@ -718,37 +568,6 @@ XLALCoincInspiralIfos (
     const char          *ifos
     );
 
-int
-XLALCoincInspiralIfosCut(
-    CoincInspiralTable **coincHead,
-    const char                *ifos
-    );
-
-int
-XLALCoincInspiralIfosDiscard(
-    CoincInspiralTable **coincHead,
-    const char          *ifos
-    );
-
-UINT8
-XLALCoincInspiralIdNumber (
-    CoincInspiralTable  *coincInspiral
-    );
-
-CoincInspiralTable *
-XLALCoincInspiralSlideCut(
-    CoincInspiralTable **coincHead,
-    int                  slideNum
-    );
-
-CoincInspiralTable *
-XLALStatCutCoincInspiral (
-    CoincInspiralTable         *eventHead,
-    CoincInspiralStatistic      coincStat,
-    CoincInspiralStatParams    *bittenLParams,
-    REAL4                       statCut
-    );
-
 int
 XLALCalcExpFitNLoudestBackground (
     CoincInspiralTable         *coincSlideHead,
@@ -785,37 +604,6 @@ XLALRateErrorCalcCoincInspiral (
     REAL4                       fitB
     );
 
-CoincInspiralTable *
-XLALRateStatCutCoincInspiral (
-    CoincInspiralTable         *eventZeroHead,
-    CoincInspiralStatistic      coincStat,
-    CoincInspiralStatParams    *bittenLParams,
-    REAL4                       statCut,
-    REAL4                       rateCut
-    );
-
-SnglInspiralTable *
-XLALCompleteCoincInspiral (
-    CoincInspiralTable         *eventHead,
-    int                         ifoList[LAL_NUM_IFO]
-    );
-
-CoincInspiralTable *
-XLALPlayTestCoincInspiral(
-    CoincInspiralTable         *eventHead,
-    LALPlaygroundDataMask      *dataType
-    );
-
-CoincInspiralTable *
-XLALMeanMassCut(
-    CoincInspiralTable         *eventHead,
-    char                       *massCut,
-    REAL4                       massRangeLow,
-    REAL4                       massRangeHigh,
-    REAL4                       mass2RangeLow,
-    REAL4                       mass2RangeHigh
-    );
-
 SnglInspiralTable *
 XLALMassCut(
     SnglInspiralTable          *eventHead,
@@ -870,6 +658,13 @@ XLALFreeSimInspiral (
     SimInspiralTable **eventHead
     );
 
+long
+XLALSimInspiralAssignIDs (
+    SimInspiralTable *head,
+    long process_id,
+    long simulation_id
+    );
+
 void
 XLALPlayTestSimInspiral(
     SimInspiralTable          **eventHead,
@@ -911,23 +706,6 @@ XLALReturnSimInspiralEndTime (
     CHAR             *ifo
     );
 
-int
-XLALSnglSimInspiralTest (
-    SimInspiralTable  **simHead,
-    SnglInspiralTable **eventHead,
-    SimInspiralTable  **missedSimHead,
-    SnglInspiralTable **missedSnglHead,
-    INT8                injectWindowNS
-    );
-
-int
-XLALCoincSimInspiralTest (
-    SimInspiralTable   **simHead,
-    CoincInspiralTable **coincHead,
-    SimInspiralTable   **missedSimHead,
-    CoincInspiralTable **missedCoincHead
-   );
-
 /* multi inspiral */
 
 void
@@ -987,15 +765,6 @@ LALCompareMultiInspiralByTime (
     const void *b
     );
 
-int
-XLALMultiSimInspiralTest (
-    SimInspiralTable  **simHead,
-    MultiInspiralTable **eventHead,
-    SimInspiralTable  **missedSimHead,
-    MultiInspiralTable **missedMultiHead,
-    INT8                injectWindowNS
-    );
-
 int
 XLALMultiInspiralIfos (
     MultiInspiralTable  *multiInspiral,
@@ -1014,17 +783,6 @@ XLALMultiInspiralSlideCut(
     int               extractSlide
     );
 
-int XLALClusterInEventID(
-    SnglInspiralTable          **inspiralList,
-    SnglInspiralClusterChoice    clusterchoice
-    );
-
-int XLALCoincSegCutSnglInspiral(
-    INT4                         startTime,
-    INT4                         endTime,
-    SnglInspiralTable          **inspiralList
-    );
-
 
 /* inspiral param accuracy */
 
