@@ -29,12 +29,6 @@
  *
  */
 
-  /* a few useful static functions */
-static INT8 geocent_end_time(const SimInspiralTable *x)
-{
-  return(XLALGPSToINT8NS(&x->geocent_end_time));
-}
-
 /*
  * A few quickies for convenience.
  */
@@ -519,238 +513,6 @@ LALCompareMultiInspiralByTime (
 }
 
 
-int
-XLALMultiSimInspiralTest (
-    SimInspiralTable  **simHead,
-    MultiInspiralTable **eventHead,
-    SimInspiralTable  **missedSimHead,
-    MultiInspiralTable **missedMultiHead,
-    INT8                injectWindowNS
-    )
-
-{
-
-  /* Note: we are assuming that both the inspiral and */
-  /* injection events are time sorted                 */
-  SimInspiralTable *thisSimEvent = *simHead;
-  SimInspiralTable *thisMissedSim= NULL;
-  SimInspiralTable *prevSimEvent = NULL;
-  MultiInspiralTable *thisEvent   = *eventHead;
-  MultiInspiralTable *prevEvent   = NULL;
-  MultiInspiralTable *thisMissed  = NULL;
-  EventIDColumn     *thisId      = NULL;
-  CHAR              ifo[LIGOMETA_IFO_MAX];
-
-  int numSimFound  = 0;
-  int coincidence = 0;
-
-  INT8 simGeocentTime, simSiteTime, inspiralTime;
-  INT8 earthRadiusNS = (INT8) ( 1e9 * 2 * LAL_REARTH_SI / LAL_C_SI );
-
-  *simHead     = NULL;
-  *eventHead   = NULL;
-
-
-  if ( ! thisEvent )
-  {
-    XLALPrintInfo( "No triggers in input data, all injections missed\n" );
-
-    *missedSimHead = thisSimEvent;
-    return(0);
-  }
-  else
-  {
-
-    /* begin loop over the sim_inspiral events */
-    while ( thisSimEvent )
-    {
-      coincidence = 0;
-      /* find the end time of the SimEvent */
-      simGeocentTime = geocent_end_time( thisSimEvent );
-
-      /* find the first inspiral event after the current sim event */
-      while ( thisEvent )
-      {
-        /* compute the time in nanosec for thisEvent */
-        inspiralTime = XLALGPSToINT8NS( &(thisEvent->end_time) );
-
-        if( inspiralTime < (simGeocentTime - earthRadiusNS - injectWindowNS ) )
-        {
-          /* discard this event and move on to the next one */
-          if ( ! *missedMultiHead )
-          {
-            *missedMultiHead = thisMissed = thisEvent;
-          }
-          else
-          {
-            thisMissed = thisMissed->next = thisEvent;
-          }
-          if ( prevEvent ) prevEvent->next = thisEvent->next;
-          thisEvent = thisEvent->next;
-          thisMissed->next = NULL;
-          XLALPrintInfo( "-" );
-        }
-        else
-        {
-          /* we have reached the negative coincincidence window */
-          break;
-        }
-      }
-
-      while ( thisEvent )
-      {
-        /* compute the time in nanosec for thisEvent */
-        inspiralTime = XLALGPSToINT8NS( &(thisEvent->end_time) );
-
-        if( inspiralTime < (simGeocentTime + earthRadiusNS + injectWindowNS ) )
-        {
-	  /*NOTE: The following assumes that the first ifo
-	    in the ifos string is the reference ifo for checking time consistency.
-	    This is consistent with coherent_inspiral.c */
-	  /* read in the first (single) ifo in the multiInspiral network (ifos) */
-	  snprintf( ifo, LIGOMETA_IFO_MAX * sizeof(CHAR),
-		       "%s", thisEvent->ifos );
-
-	  simSiteTime = XLALReturnSimInspiralEndTime( thisSimEvent, ifo );
-
-	  if ( (inspiralTime > (simSiteTime - injectWindowNS)) &&
-	       (inspiralTime < (simSiteTime + injectWindowNS)) ) {
-
-	    /* this event is within the coincidence window  */
-
-	    /* store the sim inspiral in the event_id's for this sngl */
-	    thisId = thisEvent->event_id;
-	    while ( thisId )
-	      {
-		thisId->simInspiralTable = thisSimEvent;
-		thisId = thisId->next;
-	      }
-
-	    /* store this event and move on to the next one */
-	    if ( ! *eventHead ) *eventHead = thisEvent;
-	    prevEvent = thisEvent;
-	    thisEvent = thisEvent->next;
-	    coincidence = 1;
-	    XLALPrintInfo( "+" );
-	  }
-	  else
-	    {
-	      /* discard this event and move on to the next one */
-	      if ( ! *missedMultiHead )
-		{
-		  *missedMultiHead = thisMissed = thisEvent;
-		}
-	      else
-		{
-		  thisMissed = thisMissed->next = thisEvent;
-		}
-
-	      if ( prevEvent ) prevEvent->next = thisEvent->next;
-	      thisEvent = thisEvent->next;
-	      thisMissed->next = NULL;
-	      XLALPrintInfo( "-" );
-	    }
-	}
-	else
-	  {
-	    /* we have reached the end of the positive coincincidence window */
-	    break;
-	  }
-      }
-
-      if ( coincidence )
-	{
-	  /* keep this sim event in the list and move to the next sim event */
-	  if ( ! *simHead ) *simHead = thisSimEvent;
-	  prevSimEvent = thisSimEvent;
-	  ++numSimFound;
-	  thisSimEvent = thisSimEvent->next;
-	  XLALPrintInfo( "F" );
-	}
-      else {
-        /* save this sim event in the list of missed events... */
-        if ( ! *missedSimHead )
-        {
-          *missedSimHead = thisMissedSim = thisSimEvent;
-        }
-        else
-        {
-          thisMissedSim = thisMissedSim->next = thisSimEvent;
-        }
-
-        /* ...and remove it from the list of found events */
-        if ( prevSimEvent ) prevSimEvent->next = thisSimEvent->next;
-        XLALPrintInfo( "M" );
-
-        /* move to the next sim in the list */
-        thisSimEvent = thisSimEvent->next;
-
-        /* make sure the missed sim list is terminated */
-        thisMissedSim->next = NULL;
-      }
-
-      if ( ! thisEvent )
-      {
-        /* these are no more events to process so all the rest of the */
-        /* injections must be put in the missed injections list       */
-        if ( ! *missedSimHead )
-        {
-          /* this and any subsequent events are in the missed sim list */
-          if ( thisSimEvent ) thisMissedSim = *missedSimHead = thisSimEvent;
-        }
-        else
-        {
-          if ( thisSimEvent )
-          {
-            /* append the rest of the list to the list of missed injections */
-            thisMissedSim = thisMissedSim->next = thisSimEvent;
-          }
-          else
-          {
-            /* there are no injections after this one */
-            thisMissedSim = thisMissedSim->next = NULL;
-          }
-        }
-
-        /* terminate the list of found injections correctly */
-        if ( prevSimEvent ) prevSimEvent->next = NULL;
-
-        while ( thisMissedSim )
-        {
-          /* count the number of injections just stuck in the missed list */
-          XLALPrintInfo( "M" );
-          thisMissedSim = thisMissedSim->next;
-        }
-        thisSimEvent = NULL;
-        break;
-      }
-    }
-
-    if ( thisEvent )
-    {
-      while( thisEvent )
-      {
-        /* discard this event and move on to the next one */
-        if ( ! *missedMultiHead )
-        {
-          *missedMultiHead = thisMissed = thisEvent;
-        }
-        else
-        {
-          thisMissed = thisMissed->next = thisEvent;
-        }
-        if ( prevEvent ) prevEvent->next = thisEvent->next;
-        thisEvent = thisEvent->next;
-        thisMissed->next = NULL;
-        XLALPrintInfo( "-" );
-      }
-    }
-  }
-  XLALPrintInfo( "\n" );
-  return( numSimFound );
-}
-
-
 int
 XLALMultiInspiralIfos (
     MultiInspiralTable  *multiInspiral,
