@@ -776,21 +776,34 @@ XLALFreeSimInspiral (
     )
 
 {
-  EventIDColumn        *eventId;
-
-  while ( (*eventHead)->event_id )
-  {
-    /* free any associated event_id's */
-    eventId = (*eventHead)->event_id;
-    (*eventHead)->event_id = (*eventHead)->event_id->next;
-    LALFree( eventId );
-  }
   LALFree( *eventHead );
 
   return (0);
 }
 
 
+/**
+ * Assign simulation_id values to the entries in a SimInspiral linked list.
+ * All SimInspiral rows in the list will be blamed on the given process_id,
+ * and assigned sequential simulation_ids starting with the given
+ * simulation_id.  The return value is the next simulation_id after the
+ * last one assigned to a row in the list.
+ */
+long
+XLALSimInspiralAssignIDs (
+    SimInspiralTable *head,
+    long process_id,
+    long simulation_id
+)
+{
+  for( ; head; head = head->next )
+  {
+    head->process_id = process_id;
+    head->simulation_id = simulation_id++;
+  }
+  return simulation_id;
+}
+
 
 INT8
 XLALReturnSimInspiralEndTime (
@@ -826,383 +839,3 @@ XLALReturnSimInspiralEndTime (
   }
 
 }
-
-
-int
-XLALSnglSimInspiralTest (
-    SimInspiralTable  **simHead,
-    SnglInspiralTable **eventHead,
-    SimInspiralTable  **missedSimHead,
-    SnglInspiralTable **missedSnglHead,
-    INT8                injectWindowNS
-    )
-
-{
-
-  /* Note: we are assuming that both the inspiral and */
-  /* injection events are time sorted                 */
-  SimInspiralTable *thisSimEvent = *simHead;
-  SimInspiralTable *thisMissedSim= NULL;
-  SimInspiralTable *prevSimEvent = NULL;
-  SnglInspiralTable *thisEvent   = *eventHead;
-  SnglInspiralTable *prevEvent   = NULL;
-  SnglInspiralTable *thisMissed  = NULL;
-  EventIDColumn     *thisId      = NULL;
-
-  int numSimFound  = 0;
-  int coincidence = 0;
-
-  INT8 simGeocentTime, simSiteTime, inspiralTime;
-  INT8 earthRadiusNS = (INT8) ( 1e9 * 2 * LAL_REARTH_SI / LAL_C_SI );
-
-  *simHead     = NULL;
-  *eventHead   = NULL;
-
-
-  if ( ! thisEvent )
-  {
-    XLALPrintInfo( "No triggers in input data, all injections missed\n" );
-
-    *missedSimHead = thisSimEvent;
-    return(0);
-  }
-  else
-  {
-
-    /* begin loop over the sim_inspiral events */
-    while ( thisSimEvent )
-    {
-      coincidence = 0;
-      /* find the end time of the SimEvent */
-      simGeocentTime = geocent_end_time( thisSimEvent );
-
-      /* find the first inspiral event after the current sim event */
-      while ( thisEvent )
-      {
-        /* compute the time in nanosec for thisEvent */
-        inspiralTime = XLALGPSToINT8NS( &(thisEvent->end) );
-
-        if( inspiralTime < (simGeocentTime - earthRadiusNS - injectWindowNS ) )
-        {
-          /* discard this event and move on to the next one */
-          if ( ! *missedSnglHead )
-          {
-            *missedSnglHead = thisMissed = thisEvent;
-          }
-          else
-          {
-            thisMissed = thisMissed->next = thisEvent;
-          }
-          if ( prevEvent ) prevEvent->next = thisEvent->next;
-          thisEvent = thisEvent->next;
-          thisMissed->next = NULL;
-          XLALPrintInfo( "-" );
-        }
-        else
-        {
-          /* we have reached the negative coincincidence window */
-          break;
-        }
-      }
-
-      while ( thisEvent )
-      {
-        /* compute the time in nanosec for thisEvent */
-        inspiralTime = XLALGPSToINT8NS( &(thisEvent->end) );
-
-        if( inspiralTime < (simGeocentTime + earthRadiusNS + injectWindowNS ) )
-        {
-          /* this event may be in coincidence window, need to check site
-           * end time */
-          simSiteTime = XLALReturnSimInspiralEndTime( thisSimEvent,
-              thisEvent->ifo );
-
-
-          if ( (inspiralTime > (simSiteTime - injectWindowNS)) &&
-              (inspiralTime < (simSiteTime + injectWindowNS)) )
-          {
-            /* this event is within the coincidence window  */
-
-            /* store the sim inspiral in the event_id's for this sngl */
-            thisId = thisEvent->event_id;
-            while ( thisId )
-            {
-              thisId->simInspiralTable = thisSimEvent;
-              thisId = thisId->next;
-            }
-
-            /* store this event and move on to the next one */
-            if ( ! *eventHead ) *eventHead = thisEvent;
-            prevEvent = thisEvent;
-            thisEvent = thisEvent->next;
-            coincidence = 1;
-            XLALPrintInfo( "+" );
-          }
-          else
-          {
-            /* discard this event and move on to the next one */
-            if ( ! *missedSnglHead )
-            {
-              *missedSnglHead = thisMissed = thisEvent;
-            }
-            else
-            {
-              thisMissed = thisMissed->next = thisEvent;
-            }
-
-            if ( prevEvent ) prevEvent->next = thisEvent->next;
-            thisEvent = thisEvent->next;
-            thisMissed->next = NULL;
-            XLALPrintInfo( "-" );
-          }
-        }
-        else
-        {
-          /* we have reached the end of the positive coincincidence window */
-          break;
-        }
-      }
-
-      if ( coincidence )
-      {
-        /* keep this sim event in the list and move to the next sim event */
-        if ( ! *simHead ) *simHead = thisSimEvent;
-        prevSimEvent = thisSimEvent;
-        ++numSimFound;
-        thisSimEvent = thisSimEvent->next;
-        XLALPrintInfo( "F" );
-      }
-      else
-      {
-        /* save this sim event in the list of missed events... */
-        if ( ! *missedSimHead )
-        {
-          *missedSimHead = thisMissedSim = thisSimEvent;
-        }
-        else
-        {
-          thisMissedSim = thisMissedSim->next = thisSimEvent;
-        }
-
-        /* ...and remove it from the list of found events */
-        if ( prevSimEvent ) prevSimEvent->next = thisSimEvent->next;
-        XLALPrintInfo( "M" );
-
-        /* move to the next sim in the list */
-        thisSimEvent = thisSimEvent->next;
-
-        /* make sure the missed sim list is terminated */
-        thisMissedSim->next = NULL;
-      }
-
-      if ( ! thisEvent )
-      {
-        /* these are no more events to process so all the rest of the */
-        /* injections must be put in the missed injections list       */
-        if ( ! *missedSimHead )
-        {
-          /* this and any subsequent events are in the missed sim list */
-          if ( thisSimEvent ) thisMissedSim = *missedSimHead = thisSimEvent;
-        }
-        else
-        {
-          if ( thisSimEvent )
-          {
-            /* append the rest of the list to the list of missed injections */
-            thisMissedSim = thisMissedSim->next = thisSimEvent;
-          }
-          else
-          {
-            /* there are no injections after this one */
-            thisMissedSim = thisMissedSim->next = NULL;
-          }
-        }
-
-        /* terminate the list of found injections correctly */
-        if ( prevSimEvent ) prevSimEvent->next = NULL;
-
-        while ( thisMissedSim )
-        {
-          /* count the number of injections just stuck in the missed list */
-          XLALPrintInfo( "M" );
-          thisMissedSim = thisMissedSim->next;
-        }
-        thisSimEvent = NULL;
-        break;
-      }
-    }
-
-    if ( thisEvent )
-    {
-      while( thisEvent )
-      {
-        /* discard this event and move on to the next one */
-        if ( ! *missedSnglHead )
-        {
-          *missedSnglHead = thisMissed = thisEvent;
-        }
-        else
-        {
-          thisMissed = thisMissed->next = thisEvent;
-        }
-        if ( prevEvent ) prevEvent->next = thisEvent->next;
-        thisEvent = thisEvent->next;
-        thisMissed->next = NULL;
-        XLALPrintInfo( "-" );
-      }
-    }
-  }
-  XLALPrintInfo( "\n" );
-  return( numSimFound );
-}
-
-
-
-int
-XLALCoincSimInspiralTest (
-    SimInspiralTable   **simHead,
-    CoincInspiralTable **coincHead,
-    SimInspiralTable   **missedSimHead,
-    CoincInspiralTable **missedCoincHead
-    )
-
-{
-  CoincInspiralTable    *thisCoinc       = *coincHead;
-  CoincInspiralTable    *prevCoinc       = NULL;
-  CoincInspiralTable    *thisMissedCoinc = NULL;
-  SimInspiralTable      *thisSim         = NULL;
-  SimInspiralTable      *prevSim         = NULL;
-  SimInspiralTable      *thisMissedSim   = NULL;
-  SnglInspiralTable     *thisSngl        = NULL;
-  EventIDColumn         *thisId          = NULL;
-
-  InterferometerNumber   ifoInCoinc = LAL_UNKNOWN_IFO;
-  int                    numSimFound = 0;
-
-  if ( !*coincHead )
-  {
-    XLALPrintInfo(
-        "XLALCoincSimInspiral: Empty coincInspiral passed as input" );
-    *missedSimHead = *simHead;
-    *simHead = NULL;
-    return( 0 );
-  }
-
-  *coincHead = NULL;
-
-  while( thisCoinc )
-  {
-    thisSim = NULL;
-    /* loop over the interferometers to get the event_id*/
-
-    for ( ifoInCoinc = ( InterferometerNumber ) 0; ifoInCoinc < LAL_NUM_IFO; ifoInCoinc++)
-    {
-      if ( (thisSngl = thisCoinc->snglInspiral[ifoInCoinc]) )
-      {
-        thisSim = thisSngl->event_id->simInspiralTable;
-        break;
-      }
-    }
-
-    for ( ; ifoInCoinc < LAL_NUM_IFO; ifoInCoinc++)
-    {
-      if ( (thisSngl = thisCoinc->snglInspiral[ifoInCoinc]) &&
-          (thisSim != thisSngl->event_id->simInspiralTable) )
-      {
-        thisSim = NULL;
-        break;
-      }
-    }
-
-    if ( thisSim )
-    {
-      /* thisCoinc is coincident with a thisSim */
-      thisCoinc->simInspiral = thisSim;
-
-      /* set the event_id's */
-      if ( !thisSim->event_id )
-      {
-        thisId = thisSim->event_id = LALCalloc( 1, sizeof(EventIDColumn) );
-      }
-      else
-      {
-        for ( thisId = thisSim->event_id; thisId->next; thisId = thisId->next);
-        thisId = thisId->next = LALCalloc( 1, sizeof(EventIDColumn) );
-      }
-      thisId->simInspiralTable = thisSim;
-      thisId->coincInspiralTable = thisCoinc;
-
-      if ( ! *coincHead )
-      {
-        *coincHead = thisCoinc;
-      }
-
-      XLALPrintInfo( "+" );
-      /* move on to next coinc */
-      prevCoinc = thisCoinc;
-      thisCoinc = thisCoinc->next;
-    }
-    else
-    {
-      /* discard this event and move on to the next one */
-      if ( ! *missedCoincHead )
-      {
-        *missedCoincHead = thisMissedCoinc = thisCoinc;
-      }
-      else
-      {
-        thisMissedCoinc = thisMissedCoinc->next = thisCoinc;
-      }
-
-      if ( prevCoinc ) prevCoinc->next = thisCoinc->next;
-      thisCoinc = thisCoinc->next;
-      XLALPrintInfo( "-" );
-
-      /* terminate the missed list */
-      thisMissedCoinc->next = NULL;
-    }
-  }
-
-  /* run through simInspirals, keeping only those in coincs */
-
-  thisSim = *simHead;
-  *simHead = NULL;
-
-  while( thisSim )
-  {
-    if( thisSim->event_id )
-    {
-      /* keep this event in the list and move to the next sim event */
-      if ( ! *simHead ) *simHead = thisSim;
-      prevSim = thisSim;
-      ++numSimFound;
-      thisSim = thisSim->next;
-      XLALPrintInfo( "F" );
-    }
-    else
-    {
-      /* save this sim event in the list of missed events... */
-      if ( ! *missedSimHead )
-      {
-        *missedSimHead = thisMissedSim = thisSim;
-      }
-      else
-      {
-        thisMissedSim = thisMissedSim->next = thisSim;
-      }
-
-      /* ...and remove it from the list of found events */
-      if ( prevSim ) prevSim->next = thisSim->next;
-      XLALPrintInfo( "M" );
-
-      /* move to the next sim in the list */
-      thisSim = thisSim->next;
-
-      /* make sure the missed sim list is terminated */
-      thisMissedSim->next = NULL;
-    }
-  }
-  XLALPrintInfo( "\n" );
-  return( numSimFound );
-}
-
